from pynput import mouse
import argparse
import signal
import sys


def invisible_move(mouse_controller):
    mouse_controller.move(1, 0)
    mouse_controller.move(-1, 0)


def process_args():
    parser = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter
    )
    parser.add_argument('-t', '--timeout', default=30, type=int,
                        help='set timeout in seconds after last event')
    parser.add_argument('--silent', action='store_true',
                        help="don't printing to STDOUT")

    args = parser.parse_args()
    return args


def signal_handler(_, __):
    sys.exit(0)


def listen_and_count():
    args = process_args()
    timeout = args.timeout
    silent = args.silent
    mouse_controller = mouse.Controller()
    signal.signal(signal.SIGINT, signal_handler)
    with mouse.Events() as events:
        while True:
            event = events.get(timeout)
            if event is None:
                invisible_move(mouse_controller)
                if not silent:
                    print(f'You did not interact with the mouse within {timeout} seconds')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mouse_jerk']

package_data = \
{'': ['*']}

install_requires = \
['pynput>=1.7.1,<2.0.0']

entry_points = \
{'console_scripts': ['mouse_jerk = mouse_jerk.script:main']}

setup_kwargs = {
    'name': 'mouse-jerk',
    'version': '0.4.0',
    'description': 'Small app, that help your PC to not fall asleep.',
    'long_description': None,
    'author': 'd.finko',
    'author_email': 'dmit.finn@yandex.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/gstr169/mouse_jerk',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
